﻿Imports System.Net
Imports System.Text
Imports Newtonsoft.Json
Imports Newtonsoft.Json.Linq

Public NotInheritable Class SteamHelper

    Private ReadOnly _steamBaseApiUri As String = "http://api.steampowered.com"
    Private ReadOnly _apiKey As String
    Private ReadOnly _apiVersion As String
    Private Const ApiResponseFormat As String = "json"


    Public Sub New(apiKey As String)
        Me.New(apiKey, "http://api.steampowered.com")
    End Sub


    Public Sub New(apiKey As String, rootUrl As String, Optional version As Integer = 1)
        _apiKey = apiKey
        _apiVersion = $"v{version.ToString("####")}"
        _steamBaseApiUri = rootUrl
    End Sub

    Public Function GetApiResponse(steamInterface As SteamInterface, steamMethod As String, ParamArray parameter() As String) As ApiResponse
        Using webClient As New WebClient

            Dim result As String = webClient.DownloadString(GetRequestUri(steamInterface, steamMethod, parameter))
            Dim response As ApiResponse = JsonConvert.DeserializeObject(Of ApiResponse)(result)
            Return response
        End Using
    End Function

    Private Function GetRequestUri(steamInterface As SteamInterface, steamMethod As String, ParamArray parameter() As String) As String


        Dim tempUriString = String.Format(GetBaseUri(steamInterface), steamMethod)
        For Each p In parameter
            tempUriString += $"&{p}"
        Next
        Return tempUriString
    End Function

    Private Function GetBaseUri(steamInterface As SteamInterface) As String
        'http://api.steampowered.com/ISteamUser/GetPlayerSummaries/v0002/?key={apiKey}&steamids={steamID}&format=json
        Return $"{_steamBaseApiUri}/I{steamInterface.ToString}/{{0}}/{_apiVersion}/?key={_apiKey}&format={ApiResponseFormat}"
    End Function



End Class



Public Enum SteamInterface
    SteamNews = 0
    SteamUserStats = 1
    SteamUser = 2
    PlayerService = 3
End Enum


